@@ -78,6 +78,7 @@ void ags_functional_automation_editor_workflow_test_syncsynth();
 
 CU_pSuite pSuite = NULL;
 volatile gboolean is_available;
+volatile gboolean is_terminated;
 
 extern AgsApplicationContext *ags_application_context;
 
@@ -110,8 +111,10 @@ void ags_functional_automation_editor_workflow_test_add_test()
   
   ags_functional_test_util_quit();
 
-  ags_functional_test_util_idle(AGS_FUNCTIONAL_AUTOMATION_EDITOR_WORKFLOW_TEST_DEFAULT_IDLE_TIME);
-    
+  while(!g_atomic_int_get(&is_terminated)){
+    g_usleep(G_USEC_PER_SEC / 60);
+  }
+  
   CU_cleanup_registry();
   
   exit(CU_get_error());
@@ -775,6 +778,8 @@ main(int argc, char **argv)
 
   g_atomic_int_set(&is_available,
 		   FALSE);
+  g_atomic_int_set(&is_terminated,
+		   FALSE);
   
 #if defined(AGS_TEST_CONFIG)
   ags_functional_test_util_init(&argc, &argv,
@@ -792,6 +797,9 @@ main(int argc, char **argv)
   ags_functional_test_util_do_run(argc, argv,
 				  ags_functional_automation_editor_workflow_test_add_test, &is_available);
 
+  g_atomic_int_set(&is_terminated,
+		   TRUE);
+
   g_thread_join(ags_functional_test_util_test_runner_thread());
 
   return(-1);
